@@ -55,7 +55,9 @@ def version():
 
 @cli.command()
 @click.option("-n", "--name", prompt="程序入口文件名", default="bot", show_default=True)
-@click.option("-q", "--qq", prompt="机器人qq号", type=int, required=True)
+@click.option(
+    "-q", "--qq", prompt="机器人qq号", type=int, required=True, default=0, show_default=True
+)
 @click.option(
     "--host", prompt="机器人运行host", default="http://127.0.0.1", show_default=True
 )
@@ -63,8 +65,9 @@ def version():
 def init(name, qq, host, port):
     """创建程序入口文件和配置文件"""
     plug = click.confirm("是否使用插件功能", default=True, show_default=True)
-    template = textwrap.dedent(
-        """
+    template = (
+        textwrap.dedent(
+            """
         from botoy import Action, Botoy, EventMsg, FriendMsg, GroupMsg
         from botoy import decorators as deco
 
@@ -95,7 +98,10 @@ def init(name, qq, host, port):
         if __name__ == "__main__":
             bot.run()
     """
-    ).format(qq=qq, use_plugins=plug)
+        )
+        .format(qq=qq, use_plugins=plug)
+        .strip()
+    )
 
     # main
     confirm = click.confirm(
@@ -202,7 +208,7 @@ def add(name, friend, group, event):
         )
 
     use_file = click.confirm(
-        "插件使用单文件还是文件夹形式, 默认选是表示单文件", default=True, show_default=True
+        "插件使用单文件还是文件夹形式, 默认选是表示单文件(是表示单文件，否表示文件夹)", default=True, show_default=True
     )
     if use_file:
         write_file = plugin_path_file
