@@ -1,6 +1,7 @@
 import threading
 import time
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, TypeVar, Union
+from uuid import uuid4
 
 from ..action import Action
 from ..log import logger
@@ -11,6 +12,9 @@ DEFAULT_TIMEOUT = 5 * 60
 DEFAULT_EXPIRATION = 10 * 60
 
 
+T = TypeVar("T")
+
+
 class SessionBase:
     """会话对象
     :param expiration: 持续无任何操作自动过期关闭时间
@@ -247,6 +251,39 @@ class Session(SessionBase):
             return self.pop(key, wait=True, timeout=timeout, default=default)
         return self.get(key, wait=True, timeout=timeout, default=default)
 
+    def choose(
+        self,
+        candidates: List[T],
+        retry_times: int = 1,
+        always_prompt: bool = True,
+        timeout: int = 30,
+    ) -> Optional[T]:
+        """提示用户发送序号选择列表中的一项
+        :param candidates: 选项列表
+        :param retry_times: 获取重试次数
+        :param always_prompt: 重试时是否再次发送提示
+        :param timeout: 单次获取等待超时时间(秒)
+        """
+        msg = "发送对应序号选择一项\n" + "\n".join(
+            [f"【{idx}】 {candidate}" for idx, candidate in enumerate(candidates, 1)]
+        )
+        self.send_text(msg)
+
+        count = 0
+        while count < retry_times:
+            count += 1
+            if count == 1:
+                prompt = None
+            else:
+                prompt = msg if always_prompt else None
+            what: str = self.want(str(uuid4()), prompt, pop=True, timeout=timeout)
+            try:
+                return candidates[int(what) - 1]
+            except Exception:
+                self.send_text("序号错误")
+
+        return None
+
 
 class SessionController:
     def __init__(self, session_expiration: int = None):
