@@ -1,4 +1,5 @@
 """提供框架所需的通用函数"""
+import asyncio
 import base64
 import re
 
@@ -40,3 +41,24 @@ def bind_contextvar(contextvar):
             del contextvar.get()[index]
 
     return ContextVarBind()
+
+
+def sync_run(func):
+    """同步执行异步函数，获取结果(该函数始终新建一个事件循环)
+    例如::
+
+        async def hello(name=None):
+            if name:
+                return f'Hello {name}'
+            return 'Hello'
+
+
+        print(sync_run(hello()))  # Hello
+        print(sync_run(hello('World')))  # Hello World
+    """
+    loop = asyncio.new_event_loop()
+    coro = asyncio.iscoroutine(func) and func or func()
+    try:
+        return loop.run_until_complete(coro)
+    finally:
+        loop.close()
